@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.16 2007/04/14 09:59:36 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.17 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.16 2007/04/14 09:59:36 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.17 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigActions extends SyL_Config
@@ -85,19 +85,7 @@ class SyL_ConfigActions extends SyL_Config
      * @access private
      * @var object
      */
-    var $dm = null;
-
-    /**
-     * 󥹥ȥ饯
-     *
-     * @access public
-     * @param string XMLե̾
-     */
-    function SyL_ConfigActions($file_name)
-    {
-        // ƥ饹Υ󥹥ȥ饯
-        parent::SyL_Config($file_name);
-    }
+    var $context = null;
 
     /**
      * ȥ򥻥å
@@ -108,7 +96,7 @@ class SyL_ConfigActions extends SyL_Config
      */
     function setController(&$controller)
     {
-        $this->dm =& $controller->container->getComponent('datamanager');
+        $this->context =& $controller->container->getComponent('context');
     }
 
     /**
@@ -120,7 +108,7 @@ class SyL_ConfigActions extends SyL_Config
     {
         if (SYL_WEBAPP_CACHE_DIR) {
             // åѤ
-            $key = $this->dm->getActionDir() . $this->dm->getActionFile() . $this->dm->getActionName();
+            $key = $this->context->getActionDir() . $this->context->getActionFile() . $this->context->getActionName();
             $cache =& SyL_Cache::getObject($key, 'fileupdate');
             $cache->setCacheDir(SYL_WEBAPP_CACHE_DIR . '/actions');
             $this->config = $cache->read($this->file_names);
@@ -140,44 +128,24 @@ class SyL_ConfigActions extends SyL_Config
             parent::parseXml();
         }
 
-        $this->dm->setTemplateFile($this->action_cache_value['template']);
+        if (!isset($this->config[$this->action_key])) {
+            // б륢¸ߤʤ
+            trigger_error("[SyL error] Action mapping not found (" . $this->context->getActionFile() . ")", E_USER_ERROR);
+        }
+
+        // ӥ塼פ򥻥å
+        $this->context->setViewType($this->action_cache_value['viewType']);
+
+        if (isset($this->action_cache_value['template'])) {
+            $this->context->setTemplateFile($this->action_cache_value['template']);
+        }
         if (isset($this->action_cache_value['view_parameters'])) {
             foreach ($this->action_cache_value['view_parameters'] as $name => $value) {
-                $this->dm->setViewParameter(strtolower($name), $value);
+                $this->context->setViewParameter(strtolower($name), $value);
             }
         }
-
-        if (isset($this->action_cache_value['app_component'])) {
-            foreach ($this->action_cache_value['app_component'] as $name => $value) {
-                $this->dm->cm->addAppComponent($name, $value[0], $value[1]);
-            }
-        }
-
-        if (!isset($this->config['action'])) {
-            trigger_error("[SyL error] Action mapping not found (" . $this->dm->getActionFile() . ")", E_USER_ERROR);
-        }
     }
 
-/*
-
-key = $this->dm->getActionDir() . $this->dm->getActionFile() . $this->dm->getActionName() 
-ƥץ졼Ȼ
-ƥå
-$template
-$view_type
-$attribute['customizedViewFile'], 
-$attribute['customizedViewClass']
-$this->dm->cm->addAppComponent($component_name, '', $component_priority);
-$this->dm->cm->addAppComponent($component_name, $attribute['name'], $component_priority);
-
-פʤ
-XMLѡ
-å¸
-
-
-*/
-
-
     /**
      * XMLǡƼϥɥ᥽å
      * С饤
@@ -201,7 +169,7 @@ XMLѡ
 
         // XMLϷ̤
         switch ($current_path) {
-        case '/actions/action':
+        case '/syl-actions/action':
             if ($name != '') {
                 $name = '';
                 $load = true;
@@ -213,11 +181,11 @@ XMLѡ
 
             // URLǧ
             $reg = isset($attribute['path']) ? str_replace('/', '\\/', $attribute['path']) : '(.*)';
-            if (preg_match('/^' . $reg . '$/', $this->dm->getActionFile(), $matches)) {
+            if (preg_match('/^' . $reg . '$/', $this->context->getActionFile(), $matches)) {
                 $name = $this->action_key;
-                $this->config[$name]['class']     = $this->dm->getClassName();
+                $this->config[$name]['class']     = $this->context->getClassName();
                 $this->config[$name]['type']      = 'action';
-                $this->config[$name]['file']      = $this->dm->getActionDir() . $this->dm->getActionFile();
+                $this->config[$name]['file']      = $this->context->getActionDir() . $this->context->getActionFile();
                 $this->config[$name]['reference'] = true;
                 // ¹Խ
                 $this->config[$name]['priority'] = $this->default_priority;
@@ -227,14 +195,17 @@ XMLѡ
                 $this->config[$name]['event'][$this->event][] = $name;
                 // 
                 $this->config[$name]['args'] = array();
+                // ӥ塼
+                $this->action_cache_value['viewType'] = isset($attribute['viewType']) ? $attribute['viewType'] : '';
 
                 // ǥեȥƥץ졼ȼ
-                $template = $attribute['template'];
-                for ($i=0; $i<count($matches); $i++) {
-                    $template = str_replace("\${$i}", $matches[$i], $template);
+                if ((SYL_ENV_TYPE == 'web') && isset($attribute['template'])) {
+                    $template = $attribute['template'];
+                    for ($i=0; $i<count($matches); $i++) {
+                        $template = str_replace("\${$i}", $matches[$i], $template);
+                    }
+                    $this->action_cache_value['template'] = $template;
                 }
-
-                $this->action_cache_value['template']  = $template;
                 // ӥ塼ѥ᡼å
                 $this->action_cache_value['view_parameters'] = $attribute;
             }
@@ -244,11 +215,10 @@ XMLѡ
             if (!$name) return;
 
             switch ($current_path) {
-            case '/actions/action/setter':
+            case '/syl-actions/action/setter':
                 // 쥯ȥåȥ
                 if (isset($attribute['direct']) && ($attribute['direct'] === 'true')) {
-                    // 쥯ȤξϡƬˡ_פղä
-                    $method_name = 'setter:_' . $attribute['name'] . ':true';
+                    $method_name = 'setter:' . $attribute['name'] . ':true';
                 } else {
                     $method_name = 'setter:set' . ucfirst($attribute['name']) . ':false';
                 }
@@ -256,44 +226,33 @@ XMLѡ
                 $this->config[$name]['args'][$method_name] = array();
                 break;
 
-            case '/actions/action/setter/arg':
-                $type = isset($attribute['type']) ? $attribute['type'] : 'value';
-                $ref  = (isset($attribute['reference']) && ($attribute['reference'] === 'true')) ? 'true' : 'false';
-                $this->config[$name]['args'][$method_name][] = $type . ':' . $ref . ':' . $text;
-                break;
-
-            case '/actions/action/method':
-                if (isset($attribute['actions']) && !preg_match ('/^' . preg_quote($attribute['actions']) . '$/', $this->dm->getActionName())) {
-                    $method_name = '';
-                    break;
-                }
+            case '/syl-actions/action/method':
                 if (!isset($this->config[$name]['args'])) {
                     $this->config[$name]['args'] = array();
                 }
-                $method_name = 'method:' . str_replace('{$action}', $this->dm->getActionName(), $attribute['name']);
+                $method_name = 'method:' . str_replace('{$action}', $this->context->getActionName(), $attribute['name']);
                 $this->config[$name]['args'][$method_name] = array();
                 // ٥ȥ
                 $this->config[$name]['event'][$this->event][] = $method_name;
                 break;
 
-            case '/actions/action/method/arg':
-                if ($method_name != '') {
-                    $type = isset($attribute['type']) ? $attribute['type'] : 'value';
-                    $ref  = (isset($attribute['reference']) && ($attribute['reference'] === 'true')) ? 'true' : 'false';
-                    $this->config[$name]['args'][$method_name][] = $type . ':' . $ref . ':' . $text;
-                }
+            case '/syl-actions/action/setter/arg':
+            case '/syl-actions/action/method/arg':
+                $type = isset($attribute['type']) ? $attribute['type'] : 'value';
+                $ref  = (isset($attribute['reference']) && ($attribute['reference'] === 'true')) ? 'true' : 'false';
+                $this->config[$name]['args'][$method_name][] = $type . ':' . $ref . ':' . $text;
                 break;
 
-           case '/actions/action/components/component':
+           case '/syl-actions/action/components/component':
                 if (isset($attribute['enable']) && ($attribute['enable'] === 'false')) {
                     $component_name = '';
                     return;
                 }
                 $component_name = $attribute['name'];
-                $this->config[$component_name]['class']     = $attribute['class'];
                 $this->config[$component_name]['type']      = 'component';
-                $this->config[$component_name]['file']      = isset($attribute['file']) ? $attribute['file'] : '';
-                $this->config[$component_name]['reference'] = false;
+                $this->config[$component_name]['class']     = isset($attribute['class'])  ? $attribute['class'] : $component_name;
+                $this->config[$component_name]['file']      = $attribute['file'];
+                $this->config[$component_name]['reference'] = (isset($attribute['reference']) && ($attribute['reference'] === 'true'));
                 // ¹Խ(1ʳᤤ)
                 $default_priority = $this->default_priority - 1;
                 $component_priority = isset($attribute['priority']) ? floatval($default_priority . '.' . $attribute['priority']) : $default_priority;
@@ -304,16 +263,13 @@ XMLѡ
                 $this->config[$component_name]['event'][$this->event][] = $component_name;
                 // 
                 $this->config[$component_name]['args'] = array();
-
-                // ץꥱ󥳥ݡͥ̾å
-                $this->action_cache_value['app_component'][$component_name] = array('', $component_priority);
                 break;
 
             default:
                 if (!$component_name) return;
 
                 switch ($current_path) {
-                case '/actions/action/components/component/constructor':
+                case '/syl-actions/action/components/component/constructor':
                     $method_name = 'constructor:' . (isset($attribute['static']) ? $attribute['static'] : '');
                     // 󥹥ȥ饯󥸥ե饰
                     $this->config[$component_name]['constructor'] = true;
@@ -326,13 +282,7 @@ XMLѡ
                     $this->config[$component_name]['args'][$method_name] = array();
                     break;
 
-                case '/actions/action/components/component/constructor/arg':
-                    $type = isset($attribute['type']) ? $attribute['type'] : 'value';
-                    $ref  = (isset($attribute['reference']) && ($attribute['reference'] === 'true')) ? 'true' : 'false';
-                    $this->config[$component_name]['args'][$method_name][] = $type . ':' . $ref . ':' . $text;
-                    break;
-
-                case '/actions/action/components/component/setter':
+                case '/syl-actions/action/components/component/setter':
                     // 쥯ȥåȥ
                     if (isset($attribute['direct']) && ($attribute['direct'] === 'true')) {
                         $method_name = 'setter:' . $attribute['name'] . ':true';
@@ -343,28 +293,19 @@ XMLѡ
                     $this->config[$component_name]['args'][$method_name] = array();
                     break;
 
-                case '/actions/action/components/component/setter/arg':
-                    $type = isset($attribute['type']) ? $attribute['type'] : 'value';
-                    $ref  = (isset($attribute['reference']) && ($attribute['reference'] === 'true')) ? 'true' : 'false';
-                    $this->config[$component_name]['args'][$method_name][] = $type . ':' . $ref . ':' . $text;
-                    break;
-
-                case '/actions/action/components/component/method':
+                case '/syl-actions/action/components/component/method':
                     $method_name = 'method:' . $attribute['name'];
                     $this->config[$component_name]['event'][$this->event][] = $method_name;
                     $this->config[$component_name]['args'][$method_name] = array();
                     break;
 
-                case '/actions/action/components/component/method/arg':
+                case '/syl-actions/action/components/component/setter/arg':
+                case '/syl-actions/action/components/component/constructor/arg':
+                case '/syl-actions/action/components/component/method/arg':
                     $type = isset($attribute['type']) ? $attribute['type'] : 'value';
                     $ref  = (isset($attribute['reference']) && ($attribute['reference'] === 'true')) ? 'true' : 'false';
                     $this->config[$component_name]['args'][$method_name][] = $type . ':' . $ref . ':' . $text;
                     break;
-
-                case '/actions/action/components/component/final':
-                    // ץꥱ󥳥ݡͥ̾å
-                    $this->action_cache_value['app_component'][$component_name] = array($attribute['name'], $component_priority);
-                    break;
                 }
             }
         }
