@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigComponents.php,v 1.11 2007/03/17 13:53:07 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigComponents.php,v 1.12 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigComponents.php,v 1.11 2007/03/17 13:53:07 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigComponents.php,v 1.12 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigComponents extends SyL_Config
@@ -52,18 +52,6 @@ class SyL_ConfigComponents extends SyL_Config
      */
     var $default_priority = 3;
 
-    /**
-     * 󥹥ȥ饯
-     *
-     * @access public
-     * @param string XMLե̾
-     */
-    function SyL_ConfigComponents($file_name)
-    {
-        // ƥ饹Υ󥹥ȥ饯
-        parent::SyL_Config($file_name);
-    }
-
     /**
      * XMLեβϽ
      *
@@ -106,15 +94,15 @@ class SyL_ConfigComponents extends SyL_Config
 
         // XMLϷ̤
         switch ($current_path) {
-        case '/components/component':
+        case '/syl-components/component':
             if (isset($attribute['enable']) && ($attribute['enable'] === 'false')) {
                 $name = '';
                 return;
             }
             $name = $attribute['name'];
-            $this->config[$name]['class']     = isset($attribute['class'])  ? $attribute['class']  : $name;
             $this->config[$name]['type']      = 'component';
-            $this->config[$name]['file']      = isset($attribute['file'])   ? $attribute['file']   : '';
+            $this->config[$name]['class']     = isset($attribute['class'])  ? $attribute['class']  : $name;
+            $this->config[$name]['file']      = $attribute['file'];
             $this->config[$name]['reference'] = (isset($attribute['reference']) && ($attribute['reference'] === 'true'));
             // ¹Խ
             $this->config[$name]['priority'] = isset($attribute['priority']) ? (int)$attribute['priority'] : $this->default_priority;
@@ -131,7 +119,7 @@ class SyL_ConfigComponents extends SyL_Config
             if (!$name) return;
 
             switch ($current_path) {
-            case '/components/component/constructor':
+            case '/syl-components/component/constructor':
                 $method_name = 'constructor:' . (isset($attribute['static']) ? $attribute['static'] : '');
                 // 󥹥ȥ饯󥸥ե饰
                 $this->config[$name]['constructor'] = true;
@@ -146,13 +134,13 @@ class SyL_ConfigComponents extends SyL_Config
                 $this->config[$name]['args'][$method_name] = array();
                 break;
 
-            case '/components/component/constructor/arg':
+            case '/syl-components/component/constructor/arg':
                 $type = isset($attribute['type']) ? $attribute['type'] : 'value';
                 $ref  = (isset($attribute['reference']) && ($attribute['reference'] === 'true')) ? 'true' : 'false';
                 $this->config[$name]['args'][$method_name][] = $type . ':' . $ref . ':' . $text;
                 break;
 
-            case '/components/component/setter':
+            case '/syl-components/component/setter':
                 // 쥯ȥåȥ
                 if (isset($attribute['direct']) && ($attribute['direct'] === 'true')) {
                     $method_name = 'setter:' . $attribute['name'] . ':true';
@@ -165,13 +153,13 @@ class SyL_ConfigComponents extends SyL_Config
                 $this->config[$name]['args'][$method_name] = array();
                 break;
 
-            case '/components/component/setter/arg':
+            case '/syl-components/component/setter/arg':
                 $type = isset($attribute['type']) ? $attribute['type'] : 'value';
                 $ref  = (isset($attribute['reference']) && ($attribute['reference'] === 'true')) ? 'true' : 'false';
                 $this->config[$name]['args'][$method_name][] = $type . ':' . $ref . ':' . $text;
                 break;
 
-            case '/components/component/method':
+            case '/syl-components/component/method':
                 $method_name = 'method:' . $attribute['name'];
                 // ٥ȥ
                 $event = isset($attribute['event']) ? $attribute['event'] : $event;
@@ -179,7 +167,7 @@ class SyL_ConfigComponents extends SyL_Config
                 $this->config[$name]['args'][$method_name] = array();
                 break;
 
-            case '/components/component/method/arg':
+            case '/syl-components/component/method/arg':
                 $type = isset($attribute['type']) ? $attribute['type'] : 'value';
                 $ref  = (isset($attribute['reference']) && ($attribute['reference'] === 'true')) ? 'true' : 'false';
                 $this->config[$name]['args'][$method_name][] = $type . ':' . $ref . ':' . $text;
