@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.11 2007/03/17 13:53:07 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.12 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,23 +39,11 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.11 2007/03/17 13:53:07 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.12 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigDefines extends SyL_Config
 {
-    /**
-     * 󥹥ȥ饯
-     *
-     * @access public
-     * @param string XMLե̾
-     */
-    function SyL_ConfigDefines($file_name)
-    {
-        // ƥ饹Υ󥹥ȥ饯
-        parent::SyL_Config($file_name);
-    }
-
     /**
      * XMLեβϽ
      *
@@ -90,7 +78,7 @@ class SyL_ConfigDefines extends SyL_Config
      */
     function getElement($current_path, $attribute, $text)
     {
-        if ($current_path == '/define/param') {
+        if ($current_path == '/syl-defines/define') {
             $this->config[$attribute['name']] = $text;
         }
     }
