@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.12 2007/03/17 13:53:07 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.13 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.12 2007/03/17 13:53:07 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.13 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigFilters extends SyL_Config
@@ -86,18 +86,6 @@ class SyL_ConfigFilters extends SyL_Config
      */
     var $action_file = '';
 
-    /**
-     * 󥹥ȥ饯
-     *
-     * @access public
-     * @param string XMLե̾
-     */
-    function SyL_ConfigFilters($file_name)
-    {
-        // ƥ饹Υ󥹥ȥ饯
-        parent::SyL_Config($file_name);
-    }
-
     /**
      * ȥ򥻥å
      * С饤
@@ -107,8 +95,8 @@ class SyL_ConfigFilters extends SyL_Config
      */
     function setController(&$controller)
     {
-        $dm =& $controller->container->getComponent('datamanager');
-        $this->action_file = $dm->getActionFile();
+        $context =& $controller->container->getComponent('context');
+        $this->action_file = $context->getActionFile();
     }
 
     /**
@@ -152,7 +140,7 @@ class SyL_ConfigFilters extends SyL_Config
 
         // XMLϷ̤
         switch ($current_path) {
-        case '/filters/filter':
+        case '/syl-filters/filter':
             if (isset($attribute['enable']) && ($attribute['enable'] === 'false')) {
                 $name = '';
                 return;
@@ -162,9 +150,9 @@ class SyL_ConfigFilters extends SyL_Config
             $reg = isset($attribute['path']) ? str_replace('/', '\\/', $attribute['path']) : '(.*)';
             if (preg_match('/^' . $reg . '$/', $this->action_file)) {
                 $name = '__filter_' . $attribute['name'];
-                $this->config[$name]['class']     = $attribute['class'];
                 $this->config[$name]['type']      = 'filter';
-                $this->config[$name]['file']      = isset($attribute['file']) ? $attribute['file'] : '';
+                $this->config[$name]['class']     = $attribute['class'];
+                $this->config[$name]['file']      = $attribute['file'];
                 $this->config[$name]['reference'] = false;
                 // ¹Խ
                 $this->config[$name]['priority'] = $this->default_priority;
@@ -183,34 +171,34 @@ class SyL_ConfigFilters extends SyL_Config
             if (!$name) return;
 
             switch ($current_path) {
-            case '/filters/filter/preAction':
+            case '/syl-filters/filter/preAction':
                $method_name = 'method:' . (isset($attribute['name']) ? $attribute['name'] : 'preAction');
                $this->config[$name]['event'][$this->filter_event_pre_action][] = $method_name;
                $this->config[$name]['args'][$method_name] = array();
                break;
 
-            case '/filters/filter/postAction':
+            case '/syl-filters/filter/postAction':
                $method_name = 'method:' . (isset($attribute['name']) ? $attribute['name'] : 'postAction');
                $this->config[$name]['event'][$this->filter_event_post_action][] = $method_name;
                $this->config[$name]['args'][$method_name] = array();
                break;
 
-            case '/filters/filter/preRender':
+            case '/syl-filters/filter/preRender':
                $method_name = 'method:' . (isset($attribute['name']) ? $attribute['name'] : 'preRender');
                $this->config[$name]['event'][$this->filter_event_pre_render][] = $method_name;
                $this->config[$name]['args'][$method_name]  = array();
                break;
 
-            case '/filters/filter/postRender':
+            case '/syl-filters/filter/postRender':
                $method_name = 'method:' . (isset($attribute['name']) ? $attribute['name'] : 'postRender');
                $this->config[$name]['event'][$this->filter_event_post_render][] = $method_name;
                $this->config[$name]['args'][$method_name]  = array();
                break;
 
-            case '/filters/filter/preAction/arg':
-            case '/filters/filter/postAction/arg':
-            case '/filters/filter/preRender/arg':
-            case '/filters/filter/postRender/arg':
+            case '/syl-filters/filter/preAction/arg':
+            case '/syl-filters/filter/postAction/arg':
+            case '/syl-filters/filter/preRender/arg':
+            case '/syl-filters/filter/postRender/arg':
                $type = isset($attribute['type']) ? $attribute['type'] : 'value';
                $ref  = (isset($attribute['reference']) && ($attribute['reference'] === 'true')) ? 'true' : 'false';
                $this->config[$name]['args'][$method_name][] = "{$type}:{$ref}:{$text}";
