@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigLayouts.php,v 1.4 2007/03/17 13:53:07 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigLayouts.php,v 1.5 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigLayouts.php,v 1.4 2007/03/17 13:53:07 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigLayouts.php,v 1.5 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigLayouts extends SyL_Config
@@ -52,18 +52,6 @@ class SyL_ConfigLayouts extends SyL_Config
      */
     var $action_file = '';
 
-    /**
-     * 󥹥ȥ饯
-     *
-     * @access public
-     * @param string XMLե̾
-     */
-    function SyL_ConfigLayouts($file_name)
-    {
-        // ƥ饹Υ󥹥ȥ饯
-        parent::SyL_Config($file_name);
-    }
-
     /**
      * ȥ򥻥å
      * С饤
@@ -73,8 +61,8 @@ class SyL_ConfigLayouts extends SyL_Config
      */
     function setController(&$controller)
     {
-        $dm =& $controller->container->getComponent('datamanager');
-        $this->action_file = $dm->getActionFile();
+        $context =& $controller->container->getComponent('context');
+        $this->action_file = $context->getActionFile();
     }
 
     /**
@@ -111,9 +99,8 @@ class SyL_ConfigLayouts extends SyL_Config
      */
     function getElement($current_path, $attribute, $text)
     {
-        static $name  = '';
-        static $method_name = '';
-        static $load        = false;
+        static $layout = false;
+        static $load   = false;
 
 //echo $current_path . "<br>";
         // 1ɺѤߤξʹߥå
@@ -121,9 +108,8 @@ class SyL_ConfigLayouts extends SyL_Config
 
         // XMLϷ̤
         switch ($current_path) {
-        case '/layouts/layout':
-            if ($name != '') {
-                $name = '';
+        case '/syl-layouts/layout':
+            if ($layout) {
                 $load = true;
                 return;
             }
@@ -134,7 +120,7 @@ class SyL_ConfigLayouts extends SyL_Config
             // ̾ǧ
             $reg = isset($attribute['path']) ? str_replace('/', '\\/', $attribute['path']) : '(.*)';
             if (preg_match('/^' . $reg . '$/', $this->action_file)) {
-                $name = 'dummy';
+                $layout = true;
                 $this->config['file']       = $attribute['file'];
                 $this->config['templates']  = array();
                 $this->config['view']       = array();
@@ -144,22 +130,22 @@ class SyL_ConfigLayouts extends SyL_Config
             break;
 
         default:
-            if (!$name) return;
+            if (!$layout) return;
 
             switch ($current_path) {
-            case '/layouts/layout/template':
+            case '/syl-layouts/layout/template':
                $this->config['templates'][$attribute['name']] = $attribute['file'];
                break;
 
-            case '/layouts/layout/view':
+            case '/syl-layouts/layout/view':
                 $this->config['view'][$attribute['name']] = '';
                break;
 
-            case '/layouts/layout/includes/include':
+            case '/syl-layouts/layout/includes/include':
                $this->config['includes'][] = $attribute['file'];
                break;
 
-            case '/layouts/layout/parameters/parameter':
+            case '/syl-layouts/layout/parameters/parameter':
                $this->config['parameters'][$attribute['name']] = $attribute['value'];
                break;
             }
