@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ControllerCmd.php,v 1.6 2007/02/03 11:44:45 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ControllerCmd.php,v 1.7 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -46,30 +46,11 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ControllerCmd.php,v 1.6 2007/02/03 11:44:45 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ControllerCmd.php,v 1.7 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ControllerCmd extends SyL_Controller
 {
-    /**
-     * ե륿ե̾
-     *
-     * @access private
-     * @var string
-     */
-    var $action_file_name = 'actionscmd.xml';
-
-    /**
-     * 󥹥ȥ饯
-     *
-     * @access public
-     * @param array Ķ
-     */
-    function SyL_ControllerCmd($config)
-    {
-        parent::SyL_Controller($config);
-    }
-
     /**
      * 
      *
@@ -93,7 +74,7 @@ class SyL_ControllerCmd extends SyL_Controller
     {
         // ե
         $config_file = array();
-        $config_file['actionscmd'] = SYL_APP_DIR . "/{$this->action_file_name}";
+        $config_file['actions'] = SYL_APP_DIR . "/{$this->action_file_name}";
 
         // ٥ȼ¹
         $this->raiseEvent('executeStream', $config_file);
