@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ControllerJs.php,v 1.2 2007/04/14 09:59:36 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ControllerJs.php,v 1.3 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,30 +48,11 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ControllerJs.php,v 1.2 2007/04/14 09:59:36 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ControllerJs.php,v 1.3 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ControllerJs extends SyL_Controller
 {
-    /**
-     * 󥹥ȥ饯
-     *
-     * @access public
-     * @param array Ķ
-     */
-    function SyL_ControllerJs($config)
-    {
-        // 󥭡
-        if (isset($config['action_key']) && $config['action_key']) {
-            define('SYL_ACTION_KEY', $config['action_key']);
-        } else {
-            trigger_error("[SyL error] Controller parameter action_key not exists", E_USER_ERROR);
-        }
-
-        // ƤΥ󥹥ȥ饯
-        parent::SyL_Controller($config);
-    }
-
     /**
      * 
      *
@@ -140,12 +121,6 @@ class SyL_ControllerJs extends SyL_Controller
         $this->renderStream();
         // ӥ塼ɽ¹Ը
         $this->unloadStream();
-/*
-echo "<pre>";
-print_r($this->container->components);
-echo "</pre>";
-
-*/
     }
 }
 
