@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.16 2007/04/14 09:59:36 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.17 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.16 2007/04/14 09:59:36 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.17 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ErrorWeb extends SyL_Error
@@ -157,22 +157,17 @@ class SyL_ErrorWeb extends SyL_Error
     function displayErrorTemplate($template_file, $_error_message, $_error_lines, $_error_trace, $view_type)
     {
         // ǡ饹
-        include_once SYL_INCLUDE_DIR . '/framework/SyL_DataManager.php';
-        $dm =& new SyL_DataManager($this->controller);
-        $dm->setViewParameter('viewtype', $view_type[1]);
-        if ($view_type[0] == 'layout') {
-            $dm->setViewParameter('viewlayout', 'true');
-        } else {
-            $dm->setViewParameter('viewlayout', 'false');
-        }
-        $dm->setTemplateFile($template_file);
-        $dm->setParameter('_error_message', $_error_message);
-        $dm->setParameter('_error_lines',   $_error_lines);
-        $dm->setParameter('_error_trace',   $_error_trace);
+        include_once SYL_INCLUDE_DIR . '/framework/SyL_Context.php';
+        $context =& new SyL_Context($this->controller);
+        $context->setViewType($view_type[1]);
+        $context->setTemplateFile($template_file);
+        $context->setParameter('_error_message', $_error_message);
+        $context->setParameter('_error_lines',   $_error_lines);
+        $context->setParameter('_error_trace',   $_error_trace);
 
         // ӥ塼饹
         include_once SYL_INCLUDE_DIR . '/framework/SyL_View.php';
-        $view =& SyL_View::getObject($dm);
+        $view =& SyL_View::getObject($context);
         $view->render();
 
         $response =& SyL_Response::getInstance();
