@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_FilterAuth.php,v 1.2 2007/03/24 05:20:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_FilterAuth.php,v 1.3 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Auth.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_FilterAuth.php,v 1.2 2007/03/24 05:20:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_FilterAuth.php,v 1.3 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_FilterAuth extends SyL_Filter
@@ -115,12 +115,12 @@ class SyL_FilterAuth extends SyL_Filter
      * @access public
      * @param object ǡޥ͡㥪֥
      */
-    function postAction(&$dm)
+    function postAction(&$context)
     {
         // ǧڥꥢȽ
         if (is_bool($this->login) && $this->login) {
             // TOPإ쥯
-            $dm->setRedirectUrl(SyL_Auth::getRedirectUrl());
+            $context->setRedirectUrl(SyL_Auth::getRedirectUrl());
         }
     }
 }
