@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_FilterConvertEncoding.php,v 1.2 2007/02/25 14:20:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_FilterConvertEncoding.php,v 1.3 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Filter.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_FilterConvertEncoding.php,v 1.2 2007/02/25 14:20:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_FilterConvertEncoding.php,v 1.3 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_FilterConvertEncoding extends SyL_Filter
@@ -57,13 +57,12 @@ class SyL_FilterConvertEncoding extends SyL_Filter
      * @param string 󥳡
      * @param string ѥ᡼Υ󥳡
      */
-    function preAction(&$request, $to_encoding, $from_encoding=null)
+    function preAction(&$data, $to_encoding, $from_encoding=null)
     {
-        $parameter =& $request->getParameterObject();
         if ($from_encoding) {
-            $parameter->applyParameters('mb_convert_encoding', $to_encoding, $from_encoding);
+            $data->apply('mb_convert_encoding', $to_encoding, $from_encoding);
         } else {
-            $parameter->applyParameters('mb_convert_encoding', $to_encoding);
+            $data->apply('mb_convert_encoding', $to_encoding);
         }
     }
 
@@ -75,16 +74,9 @@ class SyL_FilterConvertEncoding extends SyL_Filter
      * @param string 󥳡
      * @param string ѥ᡼Υ󥳡
      */
-    function postAction(&$dm, $to_encoding, $from_encoding=null)
+    function postAction(&$data, $to_encoding, $from_encoding=null)
     {
-        $parameters =& $dm->getParameters();
-        foreach (array_keys($parameters) as $name) {
-            if ($from_encoding) {
-                $parameters[$name] = mb_convert_encoding($parameters[$name], $to_encoding, $from_encoding);
-            } else {
-                $parameters[$name] = mb_convert_encoding($parameters[$name], $to_encoding);
-            }
-        }
+        $this->preAction($data, $to_encoding, $from_encoding);
     }
 
     /**
