@@ -6,7 +6,7 @@
  *
  * PHP version 4 (>= 4.3.x) or 5
  *
- * Copyright (C) 2006 k.watanabe
+ * Copyright (C) 2006-2007 k.watanabe
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,41 +25,29 @@
  * -----------------------------------------------------------------------------
  * @package   SyL
  * @author    k.watanabe <k.watanabe@syl.jp>
- * @copyright 2006 k.watanabe
+ * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RequestCookie.php,v 1.6 2006/12/19 13:27:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RequestCookie.php,v 1.8 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
 /**
- * ѥ᡼ݻ饹
+ * ѥץѥƥ饹
  */
-require_once SYL_INCLUDE_DIR . '/framework/SyL_Request.php';
-
-// ǥեȥåͭ
-// 30 = time() + 60 * 60 * 24 * 30
-// 0ξϥå󥯥å
-define('SYL_COOKIE_EXPIRE', time() + 60 * 60 * 24 * 30);
-// ǥեȥåѥ
-define('SYL_COOKIE_PATH', '/');
-// åɥᥤ
-// ֥ɥᥤ
-define('SYL_COOKIE_DOMAIN', '');
-// åSSLΤ߻
-define('SYL_COOKIE_SECURE', 0);
+require_once SYL_INCLUDE_DIR . '/lib/Util/SyL_UtilProperty.php';
 
 /**
  * åݻ饹
  * 
  * @package   SyL
  * @author    k.watanabe <k.watanabe@syl.jp>
- * @copyright 2006 k.watanabe
+ * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RequestCookie.php,v 1.6 2006/12/19 13:27:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RequestCookie.php,v 1.8 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
-class SyL_RequestCookie extends SyL_Request
+class SyL_RequestCookie extends SyL_UtilProperty
 {
     /**
      * 󥹥ȥ饯
@@ -72,7 +60,7 @@ class SyL_RequestCookie extends SyL_Request
         $this->parameters =& $_COOKIE;
         // ޥåݥȤͭȽ
         if (get_magic_quotes_gpc()) {
-            $this->applyParameters('stripslashes');
+            $this->apply('stripslashes');
         }
     }
 
@@ -87,10 +75,21 @@ class SyL_RequestCookie extends SyL_Request
      * @param string åͭʥɥᥤ
      * @param ing 奢HTTPS³ξˤΤߥåե饰
      */
-    function setParameter($name, $value, $expire=SYL_COOKIE_EXPIRE, $path=SYL_COOKIE_PATH, $domain=SYL_COOKIE_DOMAIN, $secure=SYL_COOKIE_SECURE )
+    function set($name, $value, $expire=SYL_COOKIE_EXPIRE, $path=SYL_COOKIE_PATH, $domain=SYL_COOKIE_DOMAIN, $secure=SYL_COOKIE_SECURE)
     {
+        // ñѴ y: ǯm: d: h: i: ʬs: 
+        if (preg_match('/^(\d+)([ymdhis])$/', $expire, $match)) {
+            switch ($match[2]) {
+            case 'y': $expire = $match[1] * (strtotime('+1 year') - time());   break;
+            case 'm': $expire = $match[1] * (strtotime('+1 month') - time());  break;
+            case 'd': $expire = $match[1] * (strtotime('+1 day') - time());    break;
+            case 'h': $expire = $match[1] * (strtotime('+1 hour') - time());   break;
+            case 'i': $expire = $match[1] * (strtotime('+1 minute') - time()); break;
+            case 's': $expire = $match[1] * (strtotime('+1 second') - time()); break;
+            }
+        }
         setcookie($name, $value, $expire, $path, $domain, $secure);
-        parent::setParameter($name, $value);
+        parent::set($name, $value);
     }
 
     /**
@@ -102,10 +101,10 @@ class SyL_RequestCookie extends SyL_Request
      * @param string åͭʥɥᥤ
      * @param ing 奢HTTPS³ξˤΤߥåե饰
      */
-    function deleteParameter($name, $path=SYL_COOKIE_PATH, $domain=SYL_COOKIE_DOMAIN, $secure=SYL_COOKIE_SECURE)
+    function delete($name, $path=SYL_COOKIE_PATH, $domain=SYL_COOKIE_DOMAIN, $secure=SYL_COOKIE_SECURE)
     {
         setcookie($name, '', time()-3600, $path, $domain, $secure);
-        parent::deleteParameter($name);
+        parent::delete($name);
     }
 
     /**
@@ -116,12 +115,12 @@ class SyL_RequestCookie extends SyL_Request
      * @param string åͭʥɥᥤ
      * @param ing 奢HTTPS³ξˤΤߥåե饰
      */
-    function deleteParameterAll($path=SYL_COOKIE_PATH, $domain=SYL_COOKIE_DOMAIN, $secure=SYL_COOKIE_SECURE)
+    function deletes($path=SYL_COOKIE_PATH, $domain=SYL_COOKIE_DOMAIN, $secure=SYL_COOKIE_SECURE)
     {
         foreach ($this->parameters as $name => $value) {
-            $this->deleteParameter($name, $path, $domain, $secure);
+            $this->delete($name, $path, $domain, $secure);
         }
-        parent::deleteParameterAll();
+        parent::deletes();
     }
 }
 
