@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.12 2007/04/14 09:59:36 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.13 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -62,7 +62,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.12 2007/04/14 09:59:36 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.13 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RouterPathinfo extends SyL_Router
@@ -81,7 +81,7 @@ class SyL_RouterPathinfo extends SyL_Router
      * @access protected
      * @param object ꥯȥ֥
      */
-    function createProperty(&$request)
+    function createProperty(&$data)
     {
         // PATH_INFOĶѿ
         $pathinfo = isset($_SERVER['PATH_INFO']) ? $_SERVER['PATH_INFO'] : '';
@@ -143,7 +143,7 @@ class SyL_RouterPathinfo extends SyL_Router
         }
 
         // ֤
-        $action_name = $request->getParameter(SYL_ACTION_KEY);
+        $action_name = $data->get(SYL_ACTION_KEY);
         if ($action_name !== null) {
             $this->action_name = $action_name;
         }
