@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterXmlrpc.php,v 1.1 2007/04/14 09:59:36 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterXmlrpc.php,v 1.2 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterXmlrpc.php,v 1.1 2007/04/14 09:59:36 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterXmlrpc.php,v 1.2 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RouterXmlrpc extends SyL_Router
@@ -58,10 +58,11 @@ class SyL_RouterXmlrpc extends SyL_Router
      * @access protected
      * @param object ꥯȥ֥
      */
-    function createProperty(&$request)
+    function createProperty(&$data)
     {
-         // syl_xmlrpc_method => SyL_RequestParameterXmlrpc饹ǥåȤ
-        $pathinfo = explode($this->action_delimiter, $request->getParameter('syl_xmlrpc_method'));
+         // syl_xmlrpc_method => SyL_DataXmlrpc饹ǥåȤ
+        $pathinfo = explode($this->action_delimiter, $data->get('syl_xmlrpc_method'));
+
         switch (count($pathinfo)) {
         case 0:
             $this->action_name = '';
