@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Auth.php,v 1.2 2007/03/24 05:20:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Auth.php,v 1.3 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Auth.php,v 1.2 2007/03/24 05:20:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Auth.php,v 1.3 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Auth
@@ -241,7 +241,7 @@ class SyL_Auth
         }
 
         if ($server_password == $client_password) {
-            $this->session->setParameter($this->session_name, $client_username);
+            $this->session->set($this->session_name, $client_username);
             SyL_Loggers::info("[Auth] Login Success. (class: " . get_class($this) . " user: {$client_username} hash: " . SYL_AUTH_PASSWORD_HASH . ")");
             return true;
         } else {
@@ -258,7 +258,7 @@ class SyL_Auth
      */
     function isLogin()
     {
-        return $this->session->isParameter($this->session_name);
+        return $this->session->is($this->session_name);
     }
 
     /**
@@ -269,9 +269,9 @@ class SyL_Auth
      */
     function doLogout()
     {
-        $client_username = $this->session->getParameter($this->session_name);
+        $client_username = $this->session->get($this->session_name);
         SyL_Loggers::info("[Auth] Logout Success. (class: " . get_class($this) . " user: {$client_username})");
-        $this->session->deleteParameters();
+        $this->session->deletes();
     }
 
     /**
@@ -289,7 +289,7 @@ class SyL_Auth
             $challenge .= chr(mt_rand(48, 126));
         }
         $challenge = str_replace('\\', '_', $challenge); // \ ֤
-        $this->session->setParameter($this->challenge_response_session_name, $challenge);
+        $this->session->set($this->challenge_response_session_name, $challenge);
         return $challenge;
     }
 
@@ -301,7 +301,7 @@ class SyL_Auth
      */
     function getChallengeCode()
     {
-        $challenge = $this->session->getParameter($this->challenge_response_session_name);
+        $challenge = $this->session->get($this->challenge_response_session_name);
         return $challenge;
     }
 
