@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Config.php,v 1.13 2007/02/17 14:28:09 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Config.php,v 1.14 2007/03/17 13:53:07 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -35,7 +35,7 @@
 /**
  * XML饹
  */
-require_once SYL_INCLUDE_DIR . '/lib/SyL_XMLParserOperation.php';
+require_once SYL_INCLUDE_DIR . '/lib/Xml/SyL_XmlReader.php';
 /**
  * å奯饹
  */
@@ -48,10 +48,10 @@ require_once SYL_INCLUDE_DIR . '/lib/SyL_Cache.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Config.php,v 1.13 2007/02/17 14:28:09 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Config.php,v 1.14 2007/03/17 13:53:07 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
-class SyL_Config extends SyL_XMLParserOperation
+class SyL_Config extends SyL_XmlReader
 {
     /**
      * ٥̾
@@ -139,12 +139,12 @@ class SyL_Config extends SyL_XMLParserOperation
      *
      * @access public
      */
-    function parseXML()
+    function parseXml()
     {
         $config = array();
         foreach ($this->file_names as $file_name) {
             parent::setFile($file_name);
-            parent::parseXML();
+            parent::parseXml();
             if (is_array($this->config)) {
                 $config += $this->config;
             }
