@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.19 2007/03/24 05:20:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.20 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -69,7 +69,7 @@ define('SYL_CONTROLLER_NAME', 'controller');
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.19 2007/03/24 05:20:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.20 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Controller
@@ -167,9 +167,16 @@ class SyL_Controller
      */
     function SyL_Controller($config)
     {
+        // 󥭡
+        if (isset($config['action_key']) && $config['action_key']) {
+            define('SYL_ACTION_KEY', $config['action_key']);
+        } else {
+            trigger_error("[SyL error] Action_key not found", E_USER_ERROR);
+        }
+
         // ץꥱ̾
         if (!isset($config['app_name']) || !$config['app_name']) {
-            trigger_error("[SyL error] Controller parameter app_name not exists", E_USER_ERROR);
+            trigger_error("[SyL error] App_name not found", E_USER_ERROR);
         }
 
         // ǥХå٥
@@ -218,7 +225,9 @@ class SyL_Controller
             if (isset($config['type']) && $config['type']) {
                 define('SYL_ENV_TYPE', strtolower($config['type']));
             } else {
-                if ((PHP_SAPI == 'cli') || ((PHP_SAPI == 'cgi') && !isset($_SERVER['REQUEST_METHOD']))) {
+                if ((PHP_SAPI == 'cgi') && !isset($_SERVER['REQUEST_METHOD'])) {
+                    trigger_error("[SyL error] Command line SAPI is CLI only", E_USER_ERROR);
+                } else if (PHP_SAPI == 'cli') {
                     define('SYL_ENV_TYPE', 'cmd');
                 } else {
                     define('SYL_ENV_TYPE', 'web');
