@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Request.php,v 1.10 2007/04/14 09:59:36 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Request.php,v 1.11 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Request.php,v 1.10 2007/04/14 09:59:36 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Request.php,v 1.11 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Request
@@ -80,12 +80,6 @@ class SyL_Request
      */
     function SyL_Request()
     {
-        // NGXgp[^IuWFNg쐬
-        $this->createParameter();
-        // t@CAbv[h́At@CAbv[hIuWFNg쐬
-        if (isset($_SERVER['CONTENT_TYPE']) && preg_match('/multipart\/form\-data/', $_SERVER['CONTENT_TYPE'])) {
-            $this->createFile();
-        }
     }
 
     /**
@@ -117,8 +111,7 @@ class SyL_Request
      function createParameter()
      {
          if ($this->parameter == null) {
-             $classname = 'SyL_RequestParameter' . ucfirst(SYL_ENV_TYPE);
-             include_once SYL_INCLUDE_DIR . "/framework/RequestParameter/{$classname}.php";
+             include_once SYL_INCLUDE_DIR . "/framework/Request/SyL_RequestParameter.php";
              $this->parameter =& new $classname();
          }
      }
@@ -131,8 +124,8 @@ class SyL_Request
      function createSession()
      {
          if ($this->session == null) {
-             include_once SYL_INCLUDE_DIR . '/framework/RequestParameter/SyL_RequestParameterSession.php';
-             $this->session =& new SyL_RequestParameterSession();
+             include_once SYL_INCLUDE_DIR . '/framework/Request/SyL_RequestSession.php';
+             $this->session =& new SyL_RequestSession();
          }
      }
 
@@ -144,8 +137,8 @@ class SyL_Request
      function createCookie()
      {
          if ($this->cookie == null) {
-             include_once SYL_INCLUDE_DIR . '/framework/RequestParameter/SyL_RequestParameterCookie.php';
-             $this->cookie =& new SyL_RequestParameterCookie();
+             include_once SYL_INCLUDE_DIR . '/framework/Request/SyL_RequestCookie.php';
+             $this->cookie =& new SyL_RequestCookie();
          }
      }
 
@@ -157,8 +150,8 @@ class SyL_Request
      function createFile()
      {
          if ($this->files == null) {
-             include_once SYL_INCLUDE_DIR . '/framework/RequestParameter/SyL_RequestParameterFile.php';
-             $this->files =& new SyL_RequestParameterFile();
+             include_once SYL_INCLUDE_DIR . '/framework/Request/SyL_RequestFile.php';
+             $this->files =& new SyL_RequestFile();
          }
      }
 
@@ -171,7 +164,10 @@ class SyL_Request
      */
     function setParameter($name, $value)
     {
-        $this->parameter->setParameter($name, $value);
+        if ($this->session == null) {
+            $this->createParameter();
+        }
+        $this->parameter->set($name, $value);
     }
 
     /**
@@ -183,7 +179,10 @@ class SyL_Request
      */
     function getParameter($name)
     {
-        return $this->parameter->getParameter($name);
+        if ($this->session == null) {
+            $this->createParameter();
+        }
+        return $this->parameter->get($name);
     }
 
     /**
@@ -194,6 +193,9 @@ class SyL_Request
      */
     function &getParameterObject()
     {
+        if ($this->session == null) {
+            $this->createParameter();
+        }
         return $this->parameter;
     }
 
@@ -209,7 +211,7 @@ class SyL_Request
         if ($this->session == null) {
             $this->createSession();
         }
-        $this->session->setParameter($name, $value);
+        $this->session->set($name, $value);
     }
 
     /**
@@ -224,7 +226,7 @@ class SyL_Request
         if ($this->session == null) {
             $this->createSession();
         }
-        return (($this->session != null) ? $this->session->getParameter($name) : null);
+        return (($this->session != null) ? $this->session->get($name) : null);
     }
 
     /**
@@ -253,7 +255,7 @@ class SyL_Request
         if ($this->cookie == null) {
             $this->createCookie();
         }
-        $this->cookie->setParameter($name, $value);
+        $this->cookie->set($name, $value);
     }
 
     /**
@@ -268,7 +270,7 @@ class SyL_Request
         if ($this->cookie == null) {
             $this->createCookie();
         }
-        return $this->cookie->getParameter($name);
+        return $this->cookie->get($name);
     }
 
     /**
@@ -295,9 +297,9 @@ class SyL_Request
     function getFile($name)
     {
         if ($this->files == null) {
-            trigger_error("[SyL error] Upload File Object Not Found", E_USER_ERROR);
+            $this->createFile();
         }
-        return $this->files->getParameter($name);
+        return $this->files->get($name);
     }
 
     /**
@@ -309,7 +311,7 @@ class SyL_Request
     function &getFileObject()
     {
         if ($this->files == null) {
-            trigger_error("[SyL error] Upload File Object Not Found", E_USER_ERROR);
+            $this->createFile();
         }
         return $this->files;
     }
