@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Response.php,v 1.10 2007/03/24 05:20:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Response.php,v 1.11 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Response.php,v 1.10 2007/03/24 05:20:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Response.php,v 1.11 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Response
@@ -285,6 +285,9 @@ class SyL_Response
     function display(&$view)
     {
         if (is_object($view)) {
+            if (is_a($view, 'SyL_ViewNull')) {
+                return;
+            }
             $data           =& $view->getRender();
             $content_type   =  $view->getContentType();
             $content_length =  $view->isContentLength();
