@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Router.php,v 1.11 2007/04/14 09:59:36 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Router.php,v 1.12 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Router.php,v 1.11 2007/04/14 09:59:36 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Router.php,v 1.12 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Router
@@ -120,12 +120,12 @@ class SyL_Router
      * @param string ܾ󥪥֥̾
      * @return object ܾ󥪥֥
      */
-    function &getObject(&$request, $rule)
+    function &getObject(&$data, $rule)
     {
         $class_name = 'SyL_Router' . ucfirst($rule);
         include_once SYL_INCLUDE_DIR . "/framework/Router/{$class_name}.php";
         $router =& new $class_name();
-        $router->createProperty($request);
+        $router->createProperty($data);
         return $router;
     }
 
@@ -135,7 +135,7 @@ class SyL_Router
      * @access protected
      * @param object ꥯȥ֥
      */
-    function createProperty(&$request)
+    function createProperty(&$data)
     {
     }
 
