@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewDefault.php,v 1.12 2007/02/22 12:55:38 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewDefault.php,v 1.13 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,23 +39,11 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewDefault.php,v 1.12 2007/02/22 12:55:38 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewDefault.php,v 1.13 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ViewDefault extends SyL_View
 {
-    /**
-     * 󥹥ȥ饯
-     *
-     * @access public
-     */
-    function SyL_ViewDefault(&$dm)
-    {
-        parent::SyL_View($dm);
-        // ƥĥפ򥻥å
-        $this->setContentType('text/html; charset=' . SYL_ENCODE_INTERNAL);
-    }
-
     /**
      * HTML󥰼¹
      * 
@@ -63,6 +51,9 @@ class SyL_ViewDefault extends SyL_View
      */
     function render()
     {
+        // ƥĥפ򥻥å
+        $this->setContentType('text/html; charset=' . SYL_ENCODE_INTERNAL);
+
         // 󤫤Υѥ᡼
         $values =& $this->getActionValues();
         foreach (array_keys($values) as $key) {
