@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewJs.php,v 1.5 2007/03/17 13:53:07 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewJs.php,v 1.6 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Js.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewJs.php,v 1.5 2007/03/17 13:53:07 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewJs.php,v 1.6 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ViewJs extends SyL_View
@@ -62,9 +62,9 @@ class SyL_ViewJs extends SyL_View
      *
      * @access public
      */
-    function SyL_ViewJs(&$dm)
+    function SyL_ViewJs(&$context, &$data)
     {
-        parent::SyL_View($dm);
+        parent::SyL_View($context, $data);
         // ƥĥפ򥻥å
         $this->setContentType('application/x-javascript; charset=' . SYL_ENCODE_INTERNAL);
         $this->js =& new SyL_Js();
@@ -77,8 +77,6 @@ class SyL_ViewJs extends SyL_View
      */
     function importJs()
     {
-        $request =& SyL_Request::getInstance();
-        $this->js->import($request->getParameter('import'));
     }
 
     /**
