@@ -27,35 +27,28 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewLayoutDefault.php,v 1.4 2007/02/22 12:55:38 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewLayoutDefault.php,v 1.5 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
 /**
- * ǥեȥ쥤ȥ饹
+ * 쥤ȥӥ塼饹
+ */
+require_once 'SyL_ViewLayout.php';
+
+/**
+ * ǥեȥ쥤ȥӥ塼饹
  *
  * @package   SyL
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewLayoutDefault.php,v 1.4 2007/02/22 12:55:38 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewLayoutDefault.php,v 1.5 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
-class SyL_ViewLayoutDefault extends SyL_View
+class SyL_ViewLayoutDefault extends SyL_ViewLayout
 {
-    /**
-     * 󥹥ȥ饯
-     *
-     * @access public
-     */
-    function SyL_ViewLayoutDefault(&$dm)
-    {
-        parent::SyL_View($dm);
-        // ƥĥפ򥻥å
-        $this->setContentType('text/html; charset=' . SYL_ENCODE_INTERNAL);
-    }
-
     /**
      * HTML󥰼¹
      * 
