@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewSmarty.php,v 1.12 2007/03/17 13:53:07 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewSmarty.php,v 1.13 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_SMARTY_DIR . 'Smarty.class.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewSmarty.php,v 1.12 2007/03/17 13:53:07 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewSmarty.php,v 1.13 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ViewSmarty extends SyL_View
@@ -61,11 +61,11 @@ class SyL_ViewSmarty extends SyL_View
      *
      * @access public
      */
-    function SyL_ViewSmarty(&$dm)
+    function SyL_ViewSmarty(&$context, &$data)
     {
-        parent::SyL_View($dm);
+        parent::SyL_View($context, $data);
 
-        $compile_dir = SYL_SMARTY_COMPILE_DIR . '/' . basename(SYL_APP_DIR);
+        $compile_dir = SYL_SMARTY_COMPILE_DIR . basename(SYL_APP_DIR);
         if (!is_dir($compile_dir)) {
             trigger_error("[SyL error] Smarty compile_dir not found ({$compile_dir})", E_USER_ERROR);
         }
@@ -73,9 +73,6 @@ class SyL_ViewSmarty extends SyL_View
         $this->smarty->compile_dir = $compile_dir;
         $this->smarty->config_dir  = SYL_SMARTY_CONFIG_DIR;
         $this->smarty->cache_dir   = SYL_SMARTY_CACHE_DIR;
-
-        // ƥĥפ򥻥å
-        $this->setContentType('text/html; charset=' . SYL_ENCODE_INTERNAL);
     }
 
     /**
@@ -85,6 +82,9 @@ class SyL_ViewSmarty extends SyL_View
      */
     function render()
     {
+        // ƥĥפ򥻥å
+        $this->setContentType('text/html; charset=' . SYL_ENCODE_INTERNAL);
+
         // 󤫤Υѥ᡼
         $values =& $this->getActionValues();
         foreach (array_keys($values) as $key) {
