@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_FormElementFile.php,v 1.9 2007/04/14 09:59:36 seasonstream Exp $
+ * @version   CVS: $Id: SyL_FormElementFile.php,v 1.10 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_FormElementFile.php,v 1.9 2007/04/14 09:59:36 seasonstream Exp $
+ * @version   CVS: $Id: SyL_FormElementFile.php,v 1.10 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_FormElementFile extends SyL_FormElement
@@ -107,19 +107,39 @@ class SyL_FormElementFile extends SyL_FormElement
      * JavaScriptϥå
      *
      * @access public
+     * @param string ե̾
      * @return string JavaScriptϥå
      */
-    function getJs()
+    function getJs($formname)
     {
         if (is_object($this->validators)) {
-            $js  = '';
-            $js .= 'var error_flag = false;' . "\n";
-            $js .= 'var element_name = "' . $this->getNames() . '";' . "\n";
-            $js .= $this->validators->getJs($this->getDisplayName(), $this->options);
-            $js .= "\n";
-            return $js;
+            $element = $this->getNames();
+            $func    = "check_{$formname}_" . $this->getName() . "(form, errors)";
+            $js      = $this->validators->getJs($this->getDisplayName());
+            $js = <<< JAVASCRIPT_CODE
+function {$func} {
+  var validation    = new SyL_Validation(form);
+  var element_name  = "{$element}";
+  var error_message = "";
+
+{$js}
+
+  if (error_message) {
+    switch (typeof(errors)) {
+    case 'object':
+      errors.setErrorMessage(element_name, error_message);
+      break;
+    case 'string':
+      document.getElementById(errors).innerHTML = error_message;
+      break;
+    }
+  }
+}
+
+JAVASCRIPT_CODE;
+            return array($func, $js);
         } else {
-            return '';
+            return array();
         }
     }
 }
