@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_FormElementRadio.php,v 1.8 2007/01/21 08:14:45 seasonstream Exp $
+ * @version   CVS: $Id: SyL_FormElementRadio.php,v 1.9 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -46,68 +46,65 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_FormElementRadio.php,v 1.8 2007/01/21 08:14:45 seasonstream Exp $
+ * @version   CVS: $Id: SyL_FormElementRadio.php,v 1.9 2007/04/14 09:59:36 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_FormElementRadio extends SyL_FormElement
 {
     /**
-     * 󥹥ȥ饯
+     * ٥ID̾
+     *
+     * @access private
+     * @var string
+     */
+    var $label = '_radio';
+    /**
+     * Ǵ֤ζڤʸ
+     *
+     * @access private
+     * @var string
+     */
+    var $separator = "&nbsp;\r\n";
+
+    /**
+     * Ǵ֤ζڤʸ򥻥å
      *
      * @access public
-     * @param string եHTML̾
-     * @param string եɽ̾
-     * @param string եǤ
-     * @param array եǤradio, select, checkboxξΤߡ
-     * @param string եǤɲ°
+     * @param string Ǵ֤ζڤʸ
      */
-    function SyL_FormElementRadio($name, $display_name, $options=array(), $value=null, $attributes=array())
+    function setSeparator($separetor)
     {
-        $this->type         = 'radio';
-        $this->name         = $name;
-        $this->display_name = $display_name;
-        $this->options      = $options;
-        // ǥեͤμ
-        $this->value      = ($value === null) ? $this->getParameter() : $value;
-        $this->attributes = $attributes;
+        $this->separator = $separetor;
     }
 
     /**
      * եHTML
-     * С饤
      *
      * @access public
-     * @param bool true: html󥳡ɤԤfalse: html󥳡ɤԤʤ
      * @return string եǤHTML
      */
-    function getHtmlTag( $html_encode=true )
+    function getHtmlTag()
     {
+        $this->setAttribute($this->name, 'name');
+        $this->setAttribute($this->type, 'type');
+
         $i = 0;
         $options = array();
         foreach ($this->options as $key => $value) {
-            $id = $this->form_name . '_' . $this->name . '_' . $i;
-            $html_element  = '';
-            $html_element .= '<input ';
-            $html_element .=   'type="'  . $this->type      . '" ';
-            $html_element .=   'id="'    . $id                      . '" ';
-            $html_element .=   'name="'  . $this->name . '" ';
-            $html_element .=   'value="' . $this->encodeHtml($key)  . '" ';
-            $html_element .= $this->getAttribute();
-            if ($key == $this->value) {
-                $html_element .= ' checked';
-            }
-            $html_element .= '>';
-            $html_element .= '<label for="' . $id . '">' . $value . '</label>';
-            $options[] = $html_element;
+            $id = $this->label . '_' . $this->name . '_' . $i;
+            $this->setAttribute($id, 'id');
+            $this->setAttribute($key, 'value');
+            $checked = ($key == $this->value) ? 'checked' : '';
+
+            $options[] = '<input ' . $this->getAttributes() . ' ' . $checked . ' /><label for="' . $id . '">' . $this->encode($value) . '</label>';
             $i++;
         }
 
-        return implode( "&nbsp;\r\n", $options );
+        return implode($this->separator, $options);
     }
 
     /**
      * եHTML
-     * С饤
      *
      * @access public
      * @return string եǤHTML
@@ -121,9 +118,8 @@ class SyL_FormElementRadio extends SyL_FormElement
                 break;
             }
         }
-        return $this->encodeHtml($label) . $this->getHtmlHidden();
+        return $this->encode($label) . $this->getHtmlHidden();
     }
 }
 
-
 ?>
