@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Console.php,v 1.4 2007/01/21 08:13:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Console.php,v 1.5 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Console.php,v 1.4 2007/01/21 08:13:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Console.php,v 1.5 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Console
@@ -65,13 +65,6 @@ class SyL_Console
      * @var resource
      */
     var $stderr;
-    /**
-     * 
-     *
-     * @access private
-     * @var array
-     */
-    var $args = array();
     /**
      * ȤƼ¹ԤȤΰ
      * falseξϥޥɼ¹Բ
@@ -121,100 +114,11 @@ class SyL_Console
      */
     function SyL_Console()
     {
-        // Ȥꤢ˴
-        while (@ob_end_clean());
-
-        ob_start();
         $this->stdin  = fopen('php://stdin',  'r');
         $this->stdout = fopen('php://stdout', 'w');
         $this->stderr = fopen('php://stderr', 'w');
 
         $this->callback_func = array(&$this, 'doCallback');
-        $this->args =  $_SERVER['argv'];
-    }
-
-    /**
-     * ¸ߤ뤫Ƚꤹ
-     *
-     * @access public
-     * @param string 
-     * @return mixed 
-     */
-    function isArg($arg)
-    {
-        return in_array($arg, $this->args);
-    }
-
-    /**
-     * 
-     * ʸ䡢Ƭˡ-פդƤϡץ󤫤
-     *
-     * @access public
-     * @param string 
-     * @return mixed 
-     */
-    function getArg($arg=null)
-    {
-        $return = '';
-        if ($arg === null) {
-            // ץ̵
-            $return = array();
-            $match = 1;
-            for ($i=1; $i<$this->getArgCount(); $i++) {
-                if ((substr($this->args[$i], 0, 1) != '-') && ($match >= 1)) {
-                    $return[] = $this->args[$i];
-                }
-                $match = (substr($this->args[$i], 0, 1) == '-') ? 0 : $match + 1;
-            }
-
-        } else if ((substr($arg, 0, 1) == '-') || !is_numeric($arg)) {
-            // ץ󤢤
-            $return = array();
-            if (substr($arg, 0, 1) != '-') {
-                $arg = '-' . $arg;
-            }
-
-            $match = false;
-            for ($i=1; $i<$this->getArgCount(); $i++) {
-                if ($this->args[$i] == $arg) {
-                    $match = false;
-                }
-                if ($match) {
-                    $return[] = $this->args[$i];
-                }
-                $match = !$match && ($this->args[$i] == $arg);
-            }
-
-        } else {
-            // ͻ
-            if (isset($this->args[$arg])) {
-                $return = $this->args[$arg];
-            }
-        }
-
-        return $return;
-    }
-
-    /**
-     * 
-     *
-     * @access public
-     * @return array 
-     */
-    function getArgs()
-    {
-        return $this->args;
-    }
-
-    /**
-     * ο
-     *
-     * @access public
-     * @return int ο
-     */
-    function getArgCount()
-    {
-        return count($this->args);
     }
 
     /**
