@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Form.php,v 1.9 2007/04/14 09:59:36 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Form.php,v 1.10 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ require_once 'SyL_Validation.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Form.php,v 1.9 2007/04/14 09:59:36 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Form.php,v 1.10 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Form
@@ -300,7 +300,7 @@ class SyL_Form
      * @access public
      * @return array ƤǤ
      */
-    function getValues()
+    function getValueAll()
     {
         $values = array();
         foreach (array_keys($this->elements) as $name) {
@@ -480,11 +480,19 @@ class SyL_Form
         $js_all_message = $this->js_all_message ? 'true' : 'false';
 
         // Хǡ
-        $validation = file_get_contents(dirname(__FILE__) . '/JsClient/SyL_FormValidater.js');
+        $validation  = '';
+        $validation .= file_get_contents(dirname(__FILE__) . '/JsClient/SyL_FormErrors.js');
+        $validation .= file_get_contents(dirname(__FILE__) . '/JsClient/SyL_Validator.js');
+        $validation .= file_get_contents(dirname(__FILE__) . '/JsClient/SyL_Validation.js');
         // ƥå᥽å
+        $funcs   = '';
         $checker = '';
         foreach (array_keys($this->elements) as $key) {
-            $checker .= $this->elements[$key]->getJs();
+            $js = $this->elements[$key]->getJs($this->getAttribute('name'));
+            if (count($js) == 2) {
+              $funcs   .= '/* ' . $this->elements[$key]->getDisplayName() . ' check */' . "\n" . $js[0] . ';' . "\n";
+              $checker .= $js[1] . "\n";
+            }
         }
 
         // פʬʥȤʤɡ˺
@@ -500,19 +508,25 @@ class SyL_Form
 </script>
 <script type="text/javascript">
 <!--
+{$checker}
+
 var {$this->js_func_name}_submit = false;
-function {$this->js_func_name}(f)
+function {$this->js_func_name}(form)
 {
   if ({$this->js_func_name}_submit) {
     return false;
   }
-  var validator = new SyL_FormValidater(f);
+  var errors = new SyL_FormErrors();
 
-{$checker}
+{$funcs}
 
   if (!{$this->js_func_name}_submit) {
-    if (validator.isError()) {
-      validator.displayErrorMessage({$js_all_message}, true, "{$this->js_id}", "{$this->js_error_header}", "{$this->js_error_footer}");
+    if (errors.isError()) {
+      errors.setDisplayElementId("{$this->js_id}");
+      errors.setDisplayAll({$js_all_message});
+      errors.setHeader("{$this->js_error_header}");
+      errors.setFooter("{$this->js_error_footer}");
+      errors.displayErrorMessage(form);
       return false;
     } else {
       {$this->js_func_name}_submit = true;
