@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_FormElement.php,v 1.10 2007/04/14 09:59:36 seasonstream Exp $
+ * @version   CVS: $Id: SyL_FormElement.php,v 1.11 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once 'SyL_Validation.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_FormElement.php,v 1.10 2007/04/14 09:59:36 seasonstream Exp $
+ * @version   CVS: $Id: SyL_FormElement.php,v 1.11 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_FormElement
@@ -178,6 +178,17 @@ class SyL_FormElement
         return $this->name;
     }
 
+    /**
+     * ̾ʣξ祪С饤ɡ
+     *
+     * @access public
+     * @return string ̾
+     */
+    function getNames()
+    {
+        return $this->getName();
+    }
+
     /**
      * ե̾
      *
@@ -403,19 +414,38 @@ class SyL_FormElement
      * JavaScriptϥå
      *
      * @access public
+     * @param string ե̾
      * @return string JavaScriptϥå
      */
-    function getJs()
+    function getJs($formname)
     {
         if (is_object($this->validators)) {
-            $js  = '';
-            $js .= 'var error_flag = false;' . "\n";
-            $js .= 'var element_name = "' . $this->getName() . '";' . "\n";
-            $js .= $this->validators->getJs($this->getDisplayName(), $this->options);
-            $js .= "\n";
-            return $js;
+            $element = $this->getName();
+            $func    = "check_{$formname}_{$element}(form, errors)";
+            $js      = $this->validators->getJs($this->getDisplayName());
+            $js = <<< JAVASCRIPT_CODE
+function {$func} {
+  var validation    = new SyL_Validation(form);
+  var element_name  = "{$element}";
+  var error_message = "";
+
+{$js}
+
+  if (error_message) {
+    switch (typeof(errors)) {
+    case 'object':
+      errors.setErrorMessage(element_name, error_message);
+      break;
+    case 'string':
+      document.getElementById(errors).innerHTML = error_message;
+      break;
+    }
+  }
+}
+JAVASCRIPT_CODE;
+            return array($func, $js);
         } else {
-            return '';
+            return array();
         }
     }
 }
