@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Validation.php,v 1.10 2007/04/14 09:59:36 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Validation.php,v 1.11 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ require_once dirname(__FILE__) . '/Validation/SyL_ValidationValidators.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Validation.php,v 1.10 2007/04/14 09:59:36 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Validation.php,v 1.11 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Validation
@@ -82,7 +82,7 @@ class SyL_Validation
     function replaceErrorMessage($name)
     {
         if ($name) {
-            $this->error_message = str_replace('{name}', $name, $this->error_message);
+            $this->error_message = str_replace(array('{name}', '%name%'), $name, $this->error_message);
         }
     }
 
@@ -117,7 +117,7 @@ class SyL_Validation
      * @param array եǤradio, select, checkboxξΤߡ
      * @return string JavaScriptå
      */
-    function getJs($display_name, $options=array())
+    function getJs($display_name)
     {
         return '';
     }
