@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ValidationValidator.php,v 1.2 2007/04/14 09:59:36 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ValidationValidator.php,v 1.3 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ValidationValidator.php,v 1.2 2007/04/14 09:59:36 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ValidationValidator.php,v 1.3 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ValidationValidator extends SyL_Validation
@@ -233,11 +233,12 @@ class SyL_ValidationValidator extends SyL_Validation
     {
         foreach ($this->parameters as $key => $value) {
             if (is_scalar($value)) {
-                $this->error_message = str_replace('{' . $key . '}', $value, $this->error_message);
+                $search = array('{' . $key . '}', '%' . $key . '%');
+                $this->error_message = str_replace($search, $value, $this->error_message);
             }
         }
-        $this->error_message = str_replace('{min_valids}', $this->min_valids, $this->error_message);
-        $this->error_message = str_replace('{max_valids}', $this->max_valids, $this->error_message);
+        $this->error_message = str_replace(array('{min_valids}', '%min_valids%'), $this->min_valids, $this->error_message);
+        $this->error_message = str_replace(array('{max_valids}', '%max_valids%'), $this->max_valids, $this->error_message);
 
         parent::replaceErrorMessage($name);
     }
@@ -250,10 +251,10 @@ class SyL_ValidationValidator extends SyL_Validation
      * @param array եǤradio, select, checkboxξΤߡ
      * @return string JavaScriptå
      */
-    function getJs($display_name, $options=array())
+    function getJs($display_name)
     {
         $this->replaceErrorMessage($display_name);
-        return $this->getJsCode($options);
+        return $this->getJsCode();
     }
 
     /**
@@ -263,7 +264,7 @@ class SyL_ValidationValidator extends SyL_Validation
      * @param array եǤradio, select, checkboxξΤߡ
      * @return string JavaScriptå
      */
-    function getJsCode($options=array())
+    function getJsCode()
     {
         return '';
     }
