@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ValidationValidators.php,v 1.2 2007/04/14 09:59:36 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ValidationValidators.php,v 1.3 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ValidationValidators.php,v 1.2 2007/04/14 09:59:36 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ValidationValidators.php,v 1.3 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ValidationValidators extends SyL_Validation
@@ -124,11 +124,11 @@ class SyL_ValidationValidators extends SyL_Validation
      * @param array եǤradio, select, checkboxξΤߡ
      * @return string JavaScriptå
      */
-    function getJs($display_name, $options=array())
+    function getJs($display_name)
     {
         $js = '';
         foreach (array_keys($this->validators) as $key) {
-            $js .= $this->validators[$key]->getJs($display_name, $options);
+            $js .= $this->validators[$key]->getJs($display_name);
         }
         return $js;
     }
