@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ValidationValidatorCompare.php,v 1.2 2007/04/14 09:59:36 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ValidationValidatorCompare.php,v 1.3 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ValidationValidatorCompare.php,v 1.2 2007/04/14 09:59:36 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ValidationValidatorCompare.php,v 1.3 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ValidationValidatorCompare extends SyL_ValidationValidator
@@ -103,26 +103,29 @@ class SyL_ValidationValidatorCompare extends SyL_ValidationValidator
      * ӸڽJavaScript
      *
      * @access public
-     * @param array եǤradio, select, checkboxξΤߡ
      * @return string JavaScriptå
      */
-    function getJsCode($options=array())
+    function getJsCode()
     {
         $options = array();
         $options[] = "'compare': '{$this->parameters['comp']}'";
         $options[] = "'min_valids': '{$this->min_valids}'";
         $options[] = "'max_valids': '{$this->max_valids}'";
         if (is_object($this->parameters['comp_object']) && is_subclass_of($this->parameters['comp_object'], 'SyL_FormElement')) {
-            $name = method_exists($this->parameters['comp_object'], 'getNames') ? $this->parameters['comp_object']->getNames() : $this->parameters['comp_object']->getName();
+            $name = $this->parameters['comp_object']->getNames();
             $options[] = "'element': '{$name}'";
         } else {
             $options[] = "'value': '{$this->parameters['comp_value']}'";
         }
 
         $js  = '';
-        $js .= 'if (!error_flag && !validator.isCompare(element_name, "' . $this->getErrorMessage() . '", {' . implode(',', $options) . '})) {' . "\n";
-        $js .= '  error_flag = true;' . "\n";
+        $js .= 'if (!error_message) {' . "\n";
+        $js .= '  var error_message_tmp = validation.isCompare(element_name, "' . $this->getErrorMessage() . '", {' . implode(',', $options) . '});' . "\n";
+        $js .= '  if (error_message_tmp) {' . "\n";
+        $js .= '    error_message = error_message_tmp;' . "\n";
+        $js .= '  }' . "\n";
         $js .= '}' . "\n";
+
         return $js;
     }
 }
