@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ValidationValidatorNumeric.php,v 1.2 2007/04/14 09:59:36 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ValidationValidatorNumeric.php,v 1.3 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ValidationValidatorNumeric.php,v 1.2 2007/04/14 09:59:36 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ValidationValidatorNumeric.php,v 1.3 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ValidationValidatorNumeric extends SyL_ValidationValidator
@@ -51,11 +51,11 @@ class SyL_ValidationValidatorNumeric extends SyL_ValidationValidator
      * @var array
      */
     var $parameters = array(
-      'min'       => null,
-      'min_error' => null,
-      'max'       => null,
-      'max_error' => null,
-      'format'    => '/^[\-\+]?[0-9]+(\.[0-9]+)?$/'
+      'dot'               => true,
+      'min'               => null,
+      'min_error_message' => null,
+      'max'               => null,
+      'max_error_message' => null
     );
 
     /**
@@ -67,8 +67,13 @@ class SyL_ValidationValidatorNumeric extends SyL_ValidationValidator
      */
     function validate($value)
     {
-        $format = $this->parameters['format'];
-        if (!preg_match($format, $value)) {
+        $regex = '';
+        if ($this->parameters['dot']) {
+            $regex = '[\-\+]?[0-9]+(\.[0-9]+)?';
+        } else {
+            $regex = '[\-\+]?[0-9]+';
+        }
+        if (!preg_match('/^' . $regex . '$/', $value)) {
             return false;
         }
 
@@ -77,8 +82,8 @@ class SyL_ValidationValidatorNumeric extends SyL_ValidationValidator
         // Ǿ͸
         if ($this->parameters['min'] !== null) {
             if ((float)$value < (float)$this->parameters['min']) {
-                if ($this->parameters['min_error'] !== null) {
-                    $this->error_message = $this->parameters['min_error'];
+                if ($this->parameters['min_error_message'] !== null) {
+                    $this->error_message = $this->parameters['min_error_message'];
                 }
                 return false;
             }
@@ -87,8 +92,8 @@ class SyL_ValidationValidatorNumeric extends SyL_ValidationValidator
         // ͸
         if ($this->parameters['max'] !== null) {
             if ((float)$value > (float)$this->parameters['max']) {
-                if ($this->parameters['max_error'] !== null) {
-                    $this->error_message = $this->parameters['max_error'];
+                if ($this->parameters['max_error_message'] !== null) {
+                    $this->error_message = $this->parameters['max_error_message'];
                 }
                 return false;
             }
@@ -101,29 +106,30 @@ class SyL_ValidationValidatorNumeric extends SyL_ValidationValidator
      * ͸ڽJavaScript
      *
      * @access public
-     * @param array եǤradio, select, checkboxξΤߡ
      * @return string JavaScriptå
      */
-    function getJsCode($options=array())
+    function getJsCode()
     {
-        $format = $this->parameters['format'];
         $min    = $this->parameters['min'];
         $max    = $this->parameters['max'];
-        $min_error = $this->parameters['min_error'];
-        $max_error = $this->parameters['max_error'];
+        $min_error_message = $this->parameters['min_error_message'];
+        $max_error_message = $this->parameters['max_error_message'];
 
         $options = array();
-        $options[] = "'format': {$format}";
+        $options[] = "'dot': " . ($this->parameters['dot'] ? 'true' : 'false');
         $options[] = "'min': '{$min}'";
         $options[] = "'max': '{$max}'";
-        $options[] = "'min_error': '{$min_error}'";
-        $options[] = "'max_error': '{$max_error}'";
+        $options[] = "'min_error_message': '{$min_error_message}'";
+        $options[] = "'max_error_message': '{$max_error_message}'";
         $options[] = "'min_valids': '{$this->min_valids}'";
         $options[] = "'max_valids': '{$this->max_valids}'";
 
-        $js  = "";
-        $js .= 'if (!error_flag && !validator.isNumeric(element_name, "' . $this->getErrorMessage() . '", {' . implode(',', $options) . '})) {' . "\n";
-        $js .= '  error_flag = true;' . "\n";
+        $js  = '';
+        $js .= 'if (!error_message) {' . "\n";
+        $js .= '  var error_message_tmp = validation.isNumeric(element_name, "' . $this->getErrorMessage() . '", {' . implode(',', $options) . '});' . "\n";
+        $js .= '  if (error_message_tmp) {' . "\n";
+        $js .= '    error_message = error_message_tmp;' . "\n";
+        $js .= '  }' . "\n";
         $js .= '}' . "\n";
         return $js;
     }
