@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ValidationValidatorRegex.php,v 1.2 2007/04/14 09:59:36 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ValidationValidatorRegex.php,v 1.3 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ValidationValidatorRegex.php,v 1.2 2007/04/14 09:59:36 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ValidationValidatorRegex.php,v 1.3 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ValidationValidatorRegex extends SyL_ValidationValidator
@@ -59,7 +59,6 @@ class SyL_ValidationValidatorRegex extends SyL_ValidationValidator
      *
      * @access public
      * @param string о
-     * @param array ȥѥ᡼
      * @return bool true: 顼̵, false: 顼
      */
     function validate($value)
@@ -75,24 +74,23 @@ class SyL_ValidationValidatorRegex extends SyL_ValidationValidator
      * ɽڽJavaScript
      *
      * @access public
-     * @param array եǤradio, select, checkboxξΤߡ
      * @return string JavaScriptå
      */
-    function getJsCode($options=array())
+    function getJsCode()
     {
         $format = $this->parameters['format'];
-        if (!$format) {
-            $format = 'false';
-        }
 
         $options = array();
         $options[] = "'format': {$format}";
         $options[] = "'min_valids': '{$this->min_valids}'";
         $options[] = "'max_valids': '{$this->max_valids}'";
 
-        $js = '';
-        $js .= 'if (!error_flag && !validator.isRegex(element_name, "' . $this->getErrorMessage() . '", {' . implode(',', $options) . '})) {' . "\n";
-        $js .= '  error_flag = true;' . "\n";
+        $js  = '';
+        $js .= 'if (!error_message) {' . "\n";
+        $js .= '  var error_message_tmp = validation.isRegex(element_name, "' . $this->getErrorMessage() . '", {' . implode(',', $options) . '});' . "\n";
+        $js .= '  if (error_message_tmp) {' . "\n";
+        $js .= '    error_message = error_message_tmp;' . "\n";
+        $js .= '  }' . "\n";
         $js .= '}' . "\n";
         return $js;
     }
