@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ValidationValidatorRequire.php,v 1.2 2007/04/14 09:59:36 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ValidationValidatorRequire.php,v 1.3 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -35,17 +35,11 @@
 /**
  * ɬܸڥ饹
  * 
- * 
- * $SyL_Validator =& SyL_Validator::create( 'require', '{name}ɬܤǤ' );
- *
- * 顼åѴʸ
- *  ʤ
- *
  * @package   SyL
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ValidationValidatorRequire.php,v 1.2 2007/04/14 09:59:36 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ValidationValidatorRequire.php,v 1.3 2007/04/24 16:49:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ValidationValidatorRequire extends SyL_ValidationValidator
@@ -79,10 +73,9 @@ class SyL_ValidationValidatorRequire extends SyL_ValidationValidator
      * ɬܸڽJavaScript
      *
      * @access public
-     * @param array եǤradio, select, checkboxξΤߡ
      * @return string JavaScriptå
      */
-    function getJsCode($options=array())
+    function getJsCode()
     {
         $options = array();
         $options[] = "'trim': " . ($this->parameters['trim'] ? 'true' : 'false');
@@ -90,8 +83,11 @@ class SyL_ValidationValidatorRequire extends SyL_ValidationValidator
         $options[] = "'max_valids': '{$this->max_valids}'";
 
         $js  = '';
-        $js .= 'if (!error_flag && !validator.isRequire(element_name, "' . $this->getErrorMessage() . '", {' . implode(',', $options) . '})) {' . "\n";
-        $js .= '  error_flag = true;' . "\n";
+        $js .= 'if (!error_message) {' . "\n";
+        $js .= '  var error_message_tmp = validation.isRequire(element_name, "' . $this->getErrorMessage() . '", {' . implode(',', $options) . '});' . "\n";
+        $js .= '  if (error_message_tmp) {' . "\n";
+        $js .= '    error_message = error_message_tmp;' . "\n";
+        $js .= '  }' . "\n";
         $js .= '}' . "\n";
         return $js;
     }
